/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EJB2And3Bean.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.examples.migrationejb21;

import javax.ejb.CreateException;
import javax.ejb.EJB;
import javax.ejb.LocalHome;
import javax.ejb.Remote;
import javax.ejb.RemoteHome;
import javax.ejb.Stateless;

/**
 * Simple stateless bean with EJB 2.1 view.
 * @author Florent Benoit
 */
@Stateless
@RemoteHome(EJB2RemoteHome.class)
@LocalHome(EJB2LocalHome.class)
@Remote(EJB3RemoteBusinessInterface.class)
public class EJB2And3Bean implements EJB3RemoteBusinessInterface {

    /**
     * Link to itself (EJB 2.x) Remote view.
     */
    @EJB
    private EJB2RemoteHome ejb2RemoteView = null;

    /**
     * Link to itself (EJB 2.x) Local view.
     */
    @EJB
    private EJB2LocalHome ejb2LocalView = null;


    /**
     * Hello world (of the EJB3 business interface).
     */
    public void hello() {
        System.out.println("Hello world EJB 3.0 !");
    }

    /**
     * Hello World (of EJB 2.1 Remote interface).
     */
    public void hello21Remote() {
        System.out.println("Hello world EJB 2.1 Remote View !");
        System.out.println("Link to itself remote = " + ejb2RemoteView);
        System.out.println("Link to itself local view = " + ejb2LocalView);
        System.out.println("Calling itself on the local view...");
        try {
            ejb2LocalView.create().hello21Local();
        } catch (CreateException e) {
           System.err.println("Cannot create local bean");
           e.printStackTrace();
        }
    }

    /**
     * Hello World (of EJB 2.1 Local interface).
     */
    public void hello21Local() {
        System.out.println("Hello world EJB 2.1 Local View !");
    }


}
